pub enum AnalyzerResourceAddress {
Static(ResourceAddress),
Dynamic {
blueprint_id: BlueprintId,
named_address: u32,
},
}Expand description
The primary address type used in the static analyzer.
The static analyzer is capable of analyzing more resource movements than just static movements, it’s capable of also analyzing movements of dynamic resources which are resources which were created within the same manifest or transaction.
This type allows for both Static and Dynamic resources to be tracked throughout the
whole codebase.
Variants
Static(ResourceAddress)
A static resource address of a resource which was created before the manifest being analyzed by the static analyzer.
Dynamic
A dynamic address of a resource which was created within the same manifest which is being analyzed by the analyzer.
Implementations
Sourceimpl AnalyzerResourceAddress
impl AnalyzerResourceAddress
Sourcepub fn new_static(address: impl Into<ResourceAddress>) -> Self
pub fn new_static(address: impl Into<ResourceAddress>) -> Self
Creates an AnalyzerResourceAddress for a resource that already exists on-ledger
with a known ResourceAddress.
Sourcepub fn new_dynamic(
blueprint_id: impl Into<BlueprintId>,
named_address: impl Into<ManifestNamedAddress>,
) -> Self
pub fn new_dynamic( blueprint_id: impl Into<BlueprintId>, named_address: impl Into<ManifestNamedAddress>, ) -> Self
Creates an AnalyzerResourceAddress for a resource that is being created within the
manifest currently being analyzed. The resource is identified by its creating blueprint,
the address reservation that will resolve to its final address, and the named address
used to reference it in subsequent manifest instructions.
Sourcepub fn is_fungible(&self) -> bool
pub fn is_fungible(&self) -> bool
Returns true if this resource is fungible. For static addresses, this is determined
from the address’s entity type. For dynamic addresses, this checks whether the creating
blueprint is the [FUNGIBLE_RESOURCE_MANAGER_BLUEPRINT].
Sourcepub fn is_non_fungible(&self) -> bool
pub fn is_non_fungible(&self) -> bool
Returns true if this resource is non-fungible, i.e. not fungible.